@@ -94,71 +94,33 @@ if sys.version_info[0] >= 3:
         return isinstance(i, int)
 
     import io
+    import locale
 
-    if sys.version_info[:2] <= (3, 3):
-        def _binary_to_string_handle(handle):
-            """Treat a binary (bytes) handle like a text (unicode) handle."""
-            # TODO, once drop all of Python 3.0 - 3.3, remove this!
-            #
-            # See also http://bugs.python.org/issue5628
-            # and http://bugs.python.org/issue13541
-            # and http://bugs.python.org/issue13464 which should be fixed in Python 3.3
-            #
-            # However, still have problems under Python 3.3.0, e.g.
-            #
-            # $ python3.3 test_SeqIO_online.py
-            # test_nuccore_X52960 (__main__.EntrezTests)
-            # Bio.Entrez.efetch('nuccore', id='X52960', ...) ... ERROR
-            # test_nucleotide_6273291 (__main__.EntrezTests)
-            # Bio.Entrez.efetch('nucleotide', id='6273291', ...) ... ERROR
-            # test_protein_16130152 (__main__.EntrezTests)
-            # Bio.Entrez.efetch('protein', id='16130152', ...) ... ERROR
-            # test_get_sprot_raw (__main__.ExPASyTests)
-            # Bio.ExPASy.get_sprot_raw("O23729") ... ok
-            # ..
-            # ValueError: I/O operation on closed file.
-            #
-            class EvilHandleHack(object):
-                """Biopython internal class to work around bugs in early versions of Python 3."""
-                def __init__(self, handle):
-                    self._handle = handle
-                    try:
-                        # If wrapping an online handle, this this is nice to have:
-                        self.url = handle.url
-                    except AttributeError:
-                        pass
-
-                def read(self, length=None):
-                    return _as_string(self._handle.read(length))
-
-                def readline(self):
-                    return _as_string(self._handle.readline())
-
-                def __iter__(self):
-                    for line in self._handle:
-                        yield _as_string(line)
-
-                def close(self):
-                    return self._handle.close()
-
-                def seek(self, pos):
-                    return self._handle.seek(pos)
-
-                def tell(self):
-                    return self._handle.tell()
-
-            return EvilHandleHack(handle)
-    else:
-        # Python 3.4 onwards, the standard library wrappers should work:
-        def _binary_to_string_handle(handle):
-            """Treat a binary (bytes) handle like a text (unicode) handle."""
-            wrapped = io.TextIOWrapper(io.BufferedReader(handle))
-            try:
-                # If wrapping an online handle, this this is nice to have:
-                wrapped.url = handle.url
-            except AttributeError:
-                pass
-            return wrapped
+    # Python 3.4 onwards, the standard library wrappers should work:
+    def _binary_to_string_handle(handle):
+        """Treat a binary (bytes) handle like a text (unicode) handle."""
+        try:
+            # If this is a network handle from urllib,
+            # the HTTP headers may tell us the encoding.
+            encoding = handle.headers.get_content_charset()
+        except AttributeError:
+            encoding = None
+        if encoding is None:
+            # The W3C recommendation is:
+            # When no explicit charset parameter is provided by the sender,
+            # media subtypes of the "text" type are defined to have a default
+            # charset value of "ISO-8859-1" when received via HTTP.
+            # "ISO-8859-1" is also known as 'latin-1'
+            # See the following for more detail:
+            # https://www.w3.org/Protocols/rfc2616/rfc2616-sec3.html#sec3.7.1
+            encoding = 'latin-1'
+        wrapped = io.TextIOWrapper(io.BufferedReader(handle), encoding=encoding)
+        try:
+            # If wrapping an online handle, this is nice to have:
+            wrapped.url = handle.url
+        except AttributeError:
+            pass
+        return wrapped
 
     # This is to avoid the deprecation warning from open(filename, "rU")
     _universal_read_mode = "r"  # text mode does universal new lines
